==> drizzle_2010.09.1802.orig.tar.gz: drizzle7-2010.09.1802/plugin/status_dictionary/dictionary.cc <==
/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
 *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
 *
 *  Copyright (C) 2010 Brian Aker
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include "config.h"
#include "plugin/status_dictionary/dictionary.h"

using namespace drizzled;

static VariablesTool *global_variables;
static VariablesTool *session_variables;


static int init(drizzled::module::Context &context)
{
  global_variables= new(std::nothrow)VariablesTool(true);
  session_variables= new(std::nothrow)VariablesTool(false);

  context.add(global_variables);
  context.add(session_variables);
  
  return 0;
}

DRIZZLE_DECLARE_PLUGIN
{
  DRIZZLE_VERSION_ID,
  "status_dictionary",
  "1.0",
  "Brian Aker",
  "Dictionary for status, statement, and variable information.",
  PLUGIN_LICENSE_GPL,
  init,
  NULL,
  NULL
}
DRIZZLE_DECLARE_PLUGIN_END;

==> drizzle_2011.03.13.orig.tar.gz: drizzle7-2011.03.13/plugin/status_dictionary/dictionary.cc <==
/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
 *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
 *
 *  Copyright (C) 2010 Brian Aker
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <config.h>
#include <plugin/status_dictionary/dictionary.h>

using namespace drizzled;

static VariablesTool *global_variables;
static VariablesTool *session_variables;


static int init(drizzled::module::Context &context)
{
  global_variables= new(std::nothrow)VariablesTool(true);
  session_variables= new(std::nothrow)VariablesTool(false);

  context.add(global_variables);
  context.add(session_variables);
  
  return 0;
}

DRIZZLE_DECLARE_PLUGIN
{
  DRIZZLE_VERSION_ID,
  "status_dictionary",
  "1.0",
  "Brian Aker",
  "Dictionary for status, statement, and variable information.",
  PLUGIN_LICENSE_GPL,
  init,
  NULL,
  NULL
}
DRIZZLE_DECLARE_PLUGIN_END;
